fhirpack.custom package — fhirpack 0.0.2b0 documentation

# fhirpack.custom package

## Subpackages

- fhirpack.custom.extraction package
  - Submodules
  - fhirpack.custom.extraction.base module
  - fhirpack.custom.extraction.sample module
  - Module contents
- fhirpack.custom.load package
  - Submodules
  - fhirpack.custom.load.base module
  - fhirpack.custom.load.sample module
  - Module contents
- fhirpack.custom.transformation package
  - Submodules
  - fhirpack.custom.transformation.base module
  - fhirpack.custom.transformation.sample module
  - Module contents

## Submodules

## fhirpack.custom.base module

class fhirpack.custom.base.PluginBaseMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.base', 'unimplementedPluginBaseMethod': <function PluginBaseMixin.unimplementedPluginBaseMethod>, '__dict__': <attribute '__dict__' of 'PluginBaseMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginBaseMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.base'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginBaseMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## fhirpack.custom.utils module

fhirpack.custom.utils.unimplementedPluginUtilsMethod()

## Module contents

class fhirpack.custom.PluginMixin

  Bases: `PluginExtractorMixin`, `PluginTransformerMixin`, `PluginLoaderMixin`

  __doc__ = None
  __module__ = 'fhirpack.custom'